package virusrecords;

import java.util.*;
import java.io.*;

/**
 * Title: VirusDatabase Class
 * Description: Facilitates in file and other information io.
 * Copyright: GPL
 * Company: University of Colorado at Colorado Springs: CS522 CVI/PRS Project
 * @author : Benjamin A. Abernathy
 * @version 1.0
 */

public class VirusDatabase {

  private Vector Keys = new Vector();
  private Vector Events = new Vector();

  private int EventCount;
  private Event DummyEvent = new Event();
  private String DBFileName = new String();
  private String DBName = new String();
  private String DBAuthor = new String();
  private String DBDate = new String();

  public VirusDatabase( String DBFN ) {
    initializeDatabase();
    EventCount = 0;
    DBFileName = DBFN;
  }

  /* Does any initialization necessary, then returns to the constructor. */
  private boolean initializeDatabase() {
    EventCount = 0;
    return true;
  }

  /* Given the file name, it will load the database into memory */
  public boolean loadDB() {
    String inputLine = new String();

    String Name = new String();
    String Author = new String();
    String Date = new String();
    String FileName = new String();
    String Description = new String();

    try
    {
      BufferedReader DBase = new BufferedReader(new InputStreamReader(
                          new FileInputStream(new File(DBFileName))));

      inputLine = DBase.readLine();
      DBName = inputLine;
      inputLine = DBase.readLine();
      DBAuthor = inputLine;
      inputLine = DBase.readLine();
      DBDate = inputLine;

      while( (inputLine != null) && (Name != null) && (Author != null) && (Date != null) && (FileName != null) && (Description != null) )
      {
        Name = DBase.readLine();
        Author = DBase.readLine();
        Date = DBase.readLine();
        FileName = DBase.readLine();
        Description = DBase.readLine();
        addEvent(Name, Author, Date, FileName, Description);
      }
      DBase.close();
    }
    catch(Exception e)
    {
      System.out.println("\nERROR: " + DBFileName + " FILE NOT FOUND");
      return( false );
    }
    return true;
  }

  /* Frees the DB after you are done with it. MUST BE CALLED BEFORE END OF
     THE PROGRAM */

  public boolean freeDB() {
    return true;

  }

  public String getDBName() {
    return( DBName );
  }

  public String getDBAuthor() {
    return( DBAuthor );
  }

  public String getDBDate() {
    return( DBDate );
  }

  public String getDBFileName() {
    return( DBFileName );
  }

  public void setDBName( String NewName ) {

    DBName = NewName;
  }

  public void setDBAuthor( String NewAuthor ) {

    DBAuthor = NewAuthor;
  }

  public void setDBDate( String NewDate ) {

    DBDate = NewDate;
  }

  public void setDBFileName( String NewFileName ) {

    DBFileName = NewFileName;
  }

  public int getEventCount() {
    return( EventCount );
  }

  public Vector getKeys() {
    return( Keys );
  }

  public Event getEventAt( int Location ) {
    Event dummy = new Event();
    Object obj = Events.elementAt(Location);
    dummy = ((Event)obj);
    return( dummy );
  }

  public void addEvent( String Name, String FileName, String Author,
                        String Date, String Description ) {
    EventCount++;
    Events.addElement(new Event(Name, FileName, Author, Date, Description));

  }

  public void editEventAt( int Location, String Name, String FileName, String Author,
                        String Date, String Description) {
    removeEventAt(Location);
    addEvent( Name, FileName, Author, Date, Description );

  }

  public void removeEventAt( int Location ) {
    Events.removeElementAt(Location);
    EventCount--;

  }

  public void updateDB() throws IOException {
    PrintWriter DBOutgoing;
    DBOutgoing = new PrintWriter(new FileWriter(DBFileName));
    DBOutgoing.println(DBName);
    DBOutgoing.println(DBAuthor);
    DBOutgoing.println(DBDate);

    int iterator = 0;
    Event Printable = new Event();

    for(; iterator < EventCount; iterator++)
    {
      Printable = getEventAt(iterator);
      DBOutgoing.println(Printable.getVirusName());
      DBOutgoing.println(Printable.getVirusFileName());
      DBOutgoing.println(Printable.getAuthor());
      DBOutgoing.println(Printable.getDate());
      DBOutgoing.println(Printable.getDate());
    }

    DBOutgoing.close();

  }
}